@@ -161,15 +161,15 @@ def column_clean(df, user_id, excl=None, semi_supervised='no', prioritize=None):
             to_dummy.append(c)
             for k, v in df[c].value_counts().iteritems():
                 if 'other' not in k:
-                    keep.append(k)
+                    keep.append((k, v))
                     data_dict['categorical'][c] = {'kept': keep, 'others': others}
                 else: 
-                    others.append(k)
+                    others.append((k, v))
         # to_dummy, but changing values that take up less than 5% of values to "other"
         elif 5 < df[c].nunique() < df.shape[0]:
             for k, v in df[c].value_counts().iteritems():
                 if v > df.shape[0]/20:
-                    keep.append(k)
+                    keep.append((k, v))
                 else:
                     others.append((k, v))
             if keep != []:
@@ -219,6 +219,8 @@ def process_data_dict(data_dict):
         out = {'feature': k}
         if list(v.values()) == [0, 1]:
             out['type'] = 'boolean'
+            out['kept'] = None
+            out['others'] = None
             for kk, vv in v.items():
                 if vv == 0:
                     out['zero'] = kk
@@ -226,8 +228,10 @@ def process_data_dict(data_dict):
                     out['one'] = kk
         else:
             out['type'] = 'dummy'
-            out['kept'] = v['kept']
+            out['kept'] = [vv[0] for vv in v['kept']]
             out['others'] = [vv[0] for vv in v['others']]
+            out['zero'] = None 
+            out['one'] = None
 
         processing.append(out)
     return pd.DataFrame(processing)
@@ -427,7 +431,7 @@ def get_fi(data, client, plot=False):
     shaps = pd.concat(shaps)
     shap_stats = shaps.groupby(by=["feature", "cluster", "feature_value"], dropna=False, as_index=False).agg(['sum', 'count', 'mean'])
     shap_stats.columns = [item[0] + '_' + item[1] for item in shap_stats.columns]
-    client.load_table_from_dataframe(shap_stats.reset_index(), 'as_shap_temp', writer='bulk_import', if_exists='overwrite')
+    # client.load_table_from_dataframe(shap_stats.reset_index(), 'as_shap_temp', writer='bulk_import', if_exists='overwrite')
 
     if plot==True:
         fig = px.bar(fi.sort_values('impt'), x='impt', y='feature', title='Overall Proportional Feature Importances', 
